/**
Author:  Luis Gerardo de la Fraga
Space3d: program to visualize polygons over 3D space
Copyright (C) 2002 Luis Gerardo de la Fraga

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Author's e-mail: fraga@cs.cinvestav.mx
Address: 
Seccin de Computacin. Dpto. de Ingeniera Elctrica
CINVESTAV-IPN                       
Av. Instituto Politcnico Nacional No. 2508
07300 Mxico, D.F. 
Mxico
**/

#include <qapplication.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qfont.h>
#include <qlayout.h>
#include <qstring.h>
#include <qcombobox.h>
#include <qlistbox.h>
#include <qhbox.h>
#include <qpen.h>
#include <qnamespace.h>
#include <qslider.h>


#include "painter.h"
#include "space3d.h"


Painter::Painter( const char *filename, QWidget *parent, const char *name )
        : QWidget( parent, name )
{
    setMinimumSize( 500, 354 );

    quit = new QPushButton( "Quit", this, "quit" );
    quit->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( quit, SIGNAL(clicked()), qApp, SLOT(quit()) );

    spheres = new Space3D( filename, this, "space3d" );
	connect( spheres, SIGNAL(changeButton()), SLOT(toButton( )) );


	light = new QComboBox( this, "light" );
	light -> insertItem( "No Lights" ); 
	light -> insertItem( "Lighting" ); 
	connect( light, SIGNAL(activated(int)), spheres, SLOT(selectLight(int)) );

	whohavelight = new QComboBox( this, "whohavelight" );
	whohavelight -> insertItem( "To Viewer" ); 
	whohavelight -> insertItem( "To Object" ); 
	connect(whohavelight,SIGNAL(activated(int)),spheres,SLOT(selLightSubject(int)) );

    QGridLayout *grid = new QGridLayout( this, 3, 2, 5 ); //3x2, 5 pixel border
    grid->addWidget( spheres, 0, 1 );
    grid->setColStretch( 1, 10 );


	QVBoxLayout *leftBox = new QVBoxLayout;
	grid->addLayout( leftBox, 0, 0 );
	leftBox->addWidget( quit );
	leftBox->addWidget( light );
	leftBox->addWidget( whohavelight );

	angle1 = new QSpinBox( 0, 360, 1,  this, "Angle1" ); 
	angle1->setWrapping ( TRUE ); 
	connect( angle1, SIGNAL(valueChanged(int)), spheres, SLOT(angValue1(int)));
	
	QLabel *alfaLabel = new QLabel( this, "alfa" );
	alfaLabel->setText( "Alfa: " );

	angle2 = new QSpinBox( 0, 360, 1,  this, "Angle2" ); 
	angle2->setWrapping ( TRUE ); 
	connect( angle2, SIGNAL(valueChanged(int)), spheres, SLOT(angValue2(int)));

	QLabel *betaLabel = new QLabel( this, "beta" );
	betaLabel->setText( "Beta: " );
	
	angle3 = new QSpinBox( 0, 360, 1,  this, "Angle3" ); 
	angle3->setWrapping ( TRUE ); 
	connect( angle3, SIGNAL(valueChanged(int)), spheres, SLOT(angValue3(int)));

	QLabel *gamaLabel = new QLabel( this, "gama" );
	gamaLabel->setText( "Gama: " );

	QGridLayout * angvals = new QGridLayout( 2, 3, 5, "Angvals" );
    angvals->addWidget( alfaLabel, 0, 0 );
    angvals->addWidget( angle1, 0, 1 );
    angvals->addWidget( betaLabel, 1, 0 );
    angvals->addWidget( angle2, 1, 1 );
    angvals->addWidget( gamaLabel, 2, 0 );
    angvals->addWidget( angle3, 2, 1 );
	grid->addLayout( angvals, 1, 0 );

	// Widgets part for animation

    initang = new QSpinBox( 0, 360, 1,  this, "InitAng" ); 
	initang->setWrapping ( TRUE ); 
	connect( initang, SIGNAL(valueChanged(int)), spheres, SLOT(angAniVal1(int)));

    stopang = new QSpinBox( 0, 360, 1,  this, "StopAng" ); 
	stopang->setWrapping ( TRUE ); 
	connect( stopang, SIGNAL(valueChanged(int)), spheres, SLOT(angAniVal2(int)));

	whichAng = new QComboBox( this, "whichAng" );
	whichAng -> insertItem( "alfa" ); 
	whichAng -> insertItem( "beta" ); 
	whichAng -> insertItem( "gama" ); 
	connect( whichAng, SIGNAL(activated(int)), spheres,SLOT(selectWhichAng(int)) );

    numimgs = new QSpinBox( 0, 50, 1,  this, "Numimgs" ); 
	// numimgs->setWrapping ( TRUE ); 
	connect( numimgs, SIGNAL(valueChanged(int)), spheres, SLOT(numImages(int)));

    anim = new QPushButton( "Anim", this, "Anim" );
	anim->setToggleButton( TRUE );
    connect( anim, SIGNAL(stateChanged( int)), spheres, SLOT(animbutton(int)) );

	QBoxLayout * hvals1 = new QHBoxLayout( 5, "HLayout1" );
	grid->addLayout( hvals1, 1, 1 );
	hvals1->addWidget( initang );
	hvals1->addWidget( stopang );
	hvals1->addWidget( whichAng );
	hvals1->addWidget( numimgs );
	hvals1->addWidget( anim );

	light_dis = new QSlider( 15,100,1,25, QSlider::Horizontal, this, "slider" );
    connect(light_dis, SIGNAL(valueChanged( int)),spheres,SLOT(dist_slider(int)) );

	QLabel * dist_label = new QLabel( this, "Dist_label" );
    connect(light_dis,SIGNAL(valueChanged(int)),dist_label,SLOT(setNum(int)) );

	QBoxLayout * hvals2 = new QHBoxLayout(  5, "HLayout2"  );
    grid->addLayout( hvals2, 2, 1 );
	hvals2->addWidget( light_dis );
	hvals2->addWidget( dist_label );

}

